# Contributing

Please follow the [Code of Conduct](https://github.com/TileDB-Inc/TileDB-ML/blob/master/CODE_OF_CONDUCT.md)
in all of your interactions with the project.

## Pull Request Process

1. Create model storage code or feature readers for ml frameworks (Tensorflow, PyTorch etc) in the appropriate folder (or create your own) or make modifications to existing ones
2. Commit the Python files
3. Write a clear commit message
4. Open a Pull Request
5. Incorporate feedback and merge once you have the sign-off of other code owners. If you do not have permission, you may request a reviewer to merge it for you.